## Description

<!-- What does this PR do? Link to related issue(s). -->

Fixes #

## Changes

<!-- List the key changes in this PR. -->

-
-

## Type of Change

- [ ] Bug fix
- [ ] New feature
- [ ] Breaking change
- [ ] Documentation update
- [ ] New attack vector
- [ ] New Skill CVE
- [ ] New framework adapter

## Checklist

- [ ] Tests pass (`uv run pytest`)
- [ ] Linters pass (`uv run ruff check .`)
- [ ] Type checks pass (`uv run mypy ziran/`)
- [ ] Documentation updated (if applicable)
- [ ] Added tests for new functionality

## Testing

<!-- How did you test these changes? -->
